..
  SPDX-FileCopyrightText: 2017 Free Software Foundation Europe e.V. <https://fsfe.org>
  SPDX-FileCopyrightText: 2017 Sebastian Schuberth <schuberth@fsfe.org>

  SPDX-License-Identifier: CC-BY-SA-4.0

=======
Credits
=======

Development Lead
----------------

- Carmen Bianca Bakker <carmenbianca@fsfe.org>

Contributors
------------

- Sebastian Schuberth <schuberth@fsfe.org>

- Max Mehl <max.mehl@fsfe.org>

- Matija Šuklje <hook@fsfe.org>

- Greg Kroah-Hartman

- Basil Peace

- Keith Maxwell

- Stefan Bakker <s.bakker777@gmail.com>

- Kirill Elagin <kirelagin@gmail.com>

- John Mulligan <jmulligan@redhat.com>

- Tuomas Siipola <tuomas@zpl.fi>

- Diego Elio Pettenò <flameeyes@flameeyes.com>


Translators
-----------

- Dutch:

  + André Ockers <ao@fsfe.org>

  + Carmen Bianca Bakker <carmenbianca@fsfe.org>

- French:

  + OliBug <act-zebug@riseup.net>

  + Vincent Lequertier <vincent@fsfe.org>

- Galician:

  + pd <euklade@gmail.com>

- German:

  + Max Mehl <max.mehl@fsfe.org>

  + Thomas Doczkal <doczkal@fsfe.org>

- Esperanto:

  + Carmen Bianca Bakker <carmenbianca@fsfe.org>

  + Tirifto <tirifto@posteo.cz>

- Italian:

 + Luca Bonissi <lucabon@fsfe.org>

- Portuguese:

  + José Vieira <jvieira33@sapo.pt>

- Spanish:

  + flow <adolflow@sindominio.net>

  + pd <euklade@gmail.com>

  + Roberto Bauglir <bauglir@fsfe.org>

- Turkish:

  + T. E. Kalayci <tekrei@member.fsf.org>

